@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-02 18:46:58
-# @Last Modified time: 2021-08-09 15:36:28
+# @Last Modified time: 2021-08-29 14:46:25
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -26,7 +26,7 @@ class DBbase(object):
     def get_conn(self):
         pass
 
-    def __execute_step(self, cursor, sql):
+    def __execute_step(self, cursor, sql, ehandling='raise'):
         '''[summary]
 
         [description]
@@ -42,8 +42,10 @@ class DBbase(object):
         try:
             cursor.execute(sql)
         except Exception as e:
-            dblogger.error(f"{e}{sql}")
-            raise ValueError(f"【Error】:{e}【Sql】:{sql};")
+            dblogger.error(f"【Error】{e}, 【error Sql】: {sql}")
+
+            if ehandling == 'raise':
+                raise ValueError(f"【Error】:{e}【Sql】:{sql}")
 
     def cur_results(self, cursor, count):
         results = cursor.fetchmany(count) if count else cursor.fetchall()
@@ -56,7 +58,7 @@ class DBbase(object):
 
         return desc, columns
 
-    def execute(self, sql, count=None, verbose=0):
+    def execute(self, sql, count=None, ehandling='raise', verbose=0):
         '''[summary]
 
         [description]
@@ -66,6 +68,7 @@ class DBbase(object):
 
         Keyword Arguments:
             count {[int]} -- [返回的结果数量] (default: {None})
+            ehandling {[str]} -- [错误处理] （raise: 错误弹出异常）
             verbose {[int]} -- [打印进程状态] （0：不打印， 1：文字进度， 2：进度条）
 
         Returns:
@@ -92,7 +95,7 @@ class DBbase(object):
         for _sql in sqls:
             results = None
             idx += 1
-            # dblogger.info(sql)
+            # dblogger.info(_sql)
             parser = SqlParse(_sql)
             comment, sql, action, tablename = parser.comment, parser.sql, parser.action, parser.tablename
             if not sql:
@@ -108,7 +111,7 @@ class DBbase(object):
             else:
                 pass
 
-            self.__execute_step(cur, sql)
+            self.__execute_step(cur, sql, ehandling=ehandling)
 
             if action == 'SELECT' and (verbose or idx == sqls_length):
                 # columns, results = cur_getresults(cur, count)
@@ -172,12 +175,18 @@ class DBCommon(DBbase):
             dblogger.info(f'【{action}】{tablename} delete {rows} rows succeed !')
             return rows, action, result
 
-    def insert(self, tablename, columns, inserttype='value', values=None, fromtable=None, condition=None, verbose=0):
+    def insert(self, tablename, columns, inserttype='value', values=None, chunksize=1000, 
+               fromtable=None, condition=None, verbose=0):
+        vlength = len(values)
         if self.__check_isauto(tablename):
             sqlcompile = SqlCompile(tablename)
             sql_for_insert = sqlcompile.insert(columns, inserttype=inserttype, values=values,
-                                               fromtable=fromtable, condition=condition)
+                                               chunksize=chunksize, fromtable=fromtable, condition=condition)
             rows, action, result = self.execute(sql_for_insert, verbose=verbose)
+            if rows != vlength % chunksize:
+                raise Exception(f'Insert Error !!!')
+
+            rows = vlength
             dblogger.info(f'【{action}】{tablename} insert {rows} rows succeed !')
             return rows, action, result
 
